@@ -11,6 +11,12 @@ class UsersService(CommonMixin, NameMixin, PrintMixin):
         self.__base = base
         self.endpoint = "/api/users"
 
+    def disable(self, user_id: int) -> None:
+        """
+        disable user
+        """
+        self.__base.post(f"/api/users/{user_id}/disable")
+
     def add_group(self, user_id: int, group_id: int) -> None:
         """
         add user to group
